@@ -1,8 +1,10 @@
 package Devel::ebug::Backend::Plugin::Basic;
-$Devel::ebug::Backend::Plugin::Basic::VERSION = '0.58';
+
 use strict;
 use warnings;
 
+our $VERSION = '0.60'; # VERSION
+
 sub register_commands {
   return (basic => { sub => \&basic });
 }
@@ -31,3 +33,38 @@ sub subroutine {
 }
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Devel::ebug::Backend::Plugin::Basic
+
+=head1 VERSION
+
+version 0.60
+
+=head1 AUTHOR
+
+Original author: Leon Brocard E<lt>acme@astray.comE<gt>
+
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
+
+Contributors:
+
+Brock Wilcox E<lt>awwaiid@thelackthereof.orgE<gt>
+
+Taisuke Yamada
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2005-2020 by Leon Brocard.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
