@@ -1,8 +1,10 @@
 package Devel::ebug::Backend::Plugin::Run;
-$Devel::ebug::Backend::Plugin::Run::VERSION = '0.59';
+
 use strict;
 use warnings;
 
+our $VERSION = '0.60'; # VERSION
+
 sub register_commands {
     return (
       next        => { sub => \&next, record => 1 },
@@ -22,7 +24,7 @@ sub next {
 sub return {
   my($req, $context) = @_;
   if ($req->{values}) {
-    $context->{stack}->[0]->{return} = $req->{values};
+    $context->{stack}->[0]->{'return'} = $req->{values};
   }
   $context->{mode} = "return"; # run until returned from subroutine
   $DB::single = 0; # run
@@ -58,3 +60,38 @@ sub step {
 
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Devel::ebug::Backend::Plugin::Run
+
+=head1 VERSION
+
+version 0.60
+
+=head1 AUTHOR
+
+Original author: Leon Brocard E<lt>acme@astray.comE<gt>
+
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
+
+Contributors:
+
+Brock Wilcox E<lt>awwaiid@thelackthereof.orgE<gt>
+
+Taisuke Yamada
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2005-2020 by Leon Brocard.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
