@@ -1,5 +1,7 @@
 package Devel::ebug::Console;
-$Devel::ebug::Console::VERSION = '0.59';
+
+our $VERSION = '0.60'; # VERSION
+
 use strict;
 use warnings;
 use lib 'lib';
@@ -40,7 +42,7 @@ sub run {
     return unless $line =~ s/^x //;
     my @result = grep { /^\Q$line/ } keys %$pad;
     if ($line =~ /^[\$\@]/) {
-      @result = map { s/^[\$\@]//; $_ } @result;
+      s/^[\$\@]// for @result;
     }
     return @result;
   };
@@ -193,9 +195,17 @@ sub show_codelines {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Devel::ebug::Console - Console front end to Devel::ebug
+Devel::ebug::Console
+
+=head1 VERSION
+
+version 0.60
 
 =head1 SYNOPSIS
 
@@ -206,20 +216,34 @@ Devel::ebug::Console - Console front end to Devel::ebug
 
 =head1 DESCRIPTION
 
-L<Devel::ebug::Console> is an interactive commmand-line front end to L<Devel::ebug>. It
+L<Devel::ebug::Console> is an interactive command-line front end to L<Devel::ebug>. It
 is a simple Perl debugger, much like perl5db.pl.
 
+=head1 NAME
+
+Devel::ebug::Console - Console front end to Devel::ebug
+
 =head1 SEE ALSO
 
 L<Devel::ebug>, L<ebug>
 
 =head1 AUTHOR
 
-Leon Brocard, C<< <acme@astray.com> >>
+Original author: Leon Brocard E<lt>acme@astray.comE<gt>
 
-=head1 COPYRIGHT
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-Copyright (C) 2005, Leon Brocard
+Contributors:
 
-This program is free software; you can redistribute it or modify it
-under the same terms as Perl itself.
+Brock Wilcox E<lt>awwaiid@thelackthereof.orgE<gt>
+
+Taisuke Yamada
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2005-2020 by Leon Brocard.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
