@@ -1,10 +1,12 @@
 package Devel::ebug::Plugin::Pad;
-$Devel::ebug::Plugin::Pad::VERSION = '0.59';
+
 use strict;
 use warnings;
 use base qw(Exporter);
 our @EXPORT = qw(pad pad_human);
 
+our $VERSION = '0.60'; # VERSION
+
 # find the pad
 sub pad {
   my($self) = @_;
@@ -35,3 +37,38 @@ sub pad_human {
 }
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Devel::ebug::Plugin::Pad
+
+=head1 VERSION
+
+version 0.60
+
+=head1 AUTHOR
+
+Original author: Leon Brocard E<lt>acme@astray.comE<gt>
+
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
+
+Contributors:
+
+Brock Wilcox E<lt>awwaiid@thelackthereof.orgE<gt>
+
+Taisuke Yamada
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2005-2020 by Leon Brocard.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
